"""
Development utilities
====================================
Tools for developers.
"""

import click
import sh
import re
from commands.helpers import TableOutput as T

# declare the commands globally
git = sh.Command("git")


def __render_message(msg):
    match = re.match(r"(?P<type>(^\[.+\]|^[a-z]+(\(.+\))?:))? ?(?P<msg>.*)", msg)
    if match and match.group("type"):
        return f"[b][blue]{match.group('type')}[/blue] {match.group('msg')}[/b]"
    return f"[b]{msg}[/b]"


@click.command(context_settings={"ignore_unknown_options": True})
@click.argument("arguments", nargs=-1)
def xpgl(arguments):
    """
    XPGL is a wrapper around git log. It provides you a tabular output of
    the most recent git commits
    """
    rows = []
    cnt = 1
    for line in git(
        "--no-pager", "log", "-n", "10", *arguments, "--pretty=%h~%d~%s~%cn~%cr"
    ):
        cols = line.rstrip("\n").split("~")
        cols[1], cols[2], cols[3], cols[4] = (
            cols[3],
            cols[4],
            __render_message(cols[2]),
            cols[1],
        )
        cols.insert(0, str(cnt))
        rows.append(cols)
        cnt += 1
    T.out(
        rows, headers=("N", "Hash", "Who", "When", "Message", "Info"), show_lines=True
    )


if __name__ == "__main__":
    xpgl()



from setuptools import setup, find_packages

long_description = "Power User Tools make your life so much easier."

setup(
    name="power-user-tools",
    version="0.1.7",
    author="dameyerdave",
    author_email="dameyerdave@gmail.com",
    url="https://github.com/dameyerdave/power-user-tools",
    description="Power User Tools make your life so much easier",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "sussh = commands.sshutils:sussh",
            "surtun = commands.sshutils:surtun",
            "suftun = commands.sshutils:suftun",
            "sumount = commands.sshutils:sumount",
            "dcc = commands.dockertools:dcc",
            "dtls = commands.dockertools:dtls",
            "dtail = commands.dockertools:dtail",
            "dtsh = commands.dockertools:dtsh",
            "dtclean = commands.dockertools:dtclean",
            "dtins = commands.dockertools:dtins",
            "dtvols = commands.dockertools:dtvols",
            "dtmounts = commands.dockertools:dtmounts",
            "xpgl = commands.devutils:xpgl",
        ]
    },
    scripts=[
        "shell/dtip",
        "shell/dtports",
        "shell/dtnet",
        "shell/dtimg",
        "shell/dtstart",
        "shell/dtstop",
        "shell/dtrestart",
        "shell/dtrm",
        "shell/xppr",
        "shell/xprandpw",
        "shell/xpgrmhistory",
        "shell/ktls",
        "shell/ktclean",
        "shell/ktdeploy",
        "shell/ktinitbash",
        "shell/ktpods",
        "shell/ktns",
    ],
    options={
        'build_scripts': {
            'executable': '/usr/bin/env python3',
        },
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords="power user tools ssh sshd reverse tunnel docker easy development",
    install_requires=[
        "click==8.1.3",
        "python-dotenv==0.21.0",
        "friendlylog==1.0.2",
        "yachalk==0.1.5",
        "rich==12.6.0",
        "sh==2.0.6",
    ],
    zip_safe=False,
)
